/// <reference types="node" />
import { IncomingMessage } from "http";
export declare const AUTH_SYNC_KEY = "auth_sync_key";
export declare type IdTokenData = {
    sub: string;
    aud: string;
    email_verified: boolean;
    event_id: string;
    token_use: "id";
    auth_time: number;
    iss: string;
    "cognito:username": string;
    exp: number;
    iat: number;
    email: string;
};
export declare type AccessTokenData = {
    sub: string;
    event_id: string;
    token_use: string;
    scope: string;
    auth_time: number;
    iss: string;
    exp: number;
    iat: number;
    jti: string;
    client_id: string;
    username: string;
};
export declare type AuthTokens = {
    accessTokenData: AccessTokenData;
    idTokenData: IdTokenData;
    idToken: string;
    accessToken: string;
} | null;
declare type AWSCognitoPublicPem = {
    kid: string;
    pem: string;
};
export declare function createGetServerSideAuth({ pems, }: {
    pems: AWSCognitoPublicPem[];
}): (req: IncomingMessage) => AuthTokens;
declare type LoginFunction = (redirectAfterSignIn?: string) => void;
declare type LogoutFunction = (redirectAfterSignOut?: string) => void;
export declare function createUseAuth({ pems }: {
    pems: AWSCognitoPublicPem[];
}): (initialAuth: AuthTokens) => AuthTokens;
export declare function useAuthFunctions(): {
    login: LoginFunction;
    logout: LogoutFunction;
};
export default function useAuthRedirect(onToken: (token: string | null) => void): null;
export {};
